
# This file was generated by 'versioneer.py' (0.28) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2024-05-13T12:45:55+0200",
 "dirty": false,
 "error": null,
 "full-revisionid": "dd5c5cb8b06349c30e5b1cee5d3100b91d5f4670",
 "version": "0.60.0rc1"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
